]> git.sesse.net Git - cubemap/blobdiff - client.h
Rename header_or_error to header_or_short_response, as it will soon be able to contai...
[cubemap] / client.h
index 954ad41967878b123ea388fe9110f7d6b4069603..2ee478375fd9edcda5da464c90907b0e41f7e0e6 100644 (file)
--- a/client.h
+++ b/client.h
@@ -44,7 +44,7 @@ struct Client {
        std::string referer;
        std::string user_agent;
 
-       enum State { READING_REQUEST, SENDING_HEADER, SENDING_DATA, SENDING_ERROR, WAITING_FOR_KEYFRAME, PREBUFFERING };
+       enum State { READING_REQUEST, SENDING_HEADER, SENDING_DATA, SENDING_SHORT_RESPONSE, WAITING_FOR_KEYFRAME, PREBUFFERING };
        State state;
 
        // The HTTP request, as sent by the client. If we are in READING_REQUEST,
@@ -56,14 +56,16 @@ struct Client {
        std::string url;
        Stream *stream;
 
-       // The header we want to send. This is nominally a copy of Stream::header,
-       // but since that might change on reconnects etc., we keep a local copy here.
-       // Only relevant for SENDING_HEADER or SENDING_ERROR; blank otherwise.
-       std::string header_or_error;
+       // The header we want to send, or the response with headers if we know
+       // it in its entirety after reading the request (typically an error).
+       // This is nominally a copy of Stream::header, but since that might
+       // change on reconnects etc., we keep a local copy here. Only relevant
+       // for SENDING_HEADER or SENDING_SHORT_RESPONSE; blank otherwise.
+       std::string header_or_short_response;
 
        // Number of bytes we've sent of the header. Only relevant for SENDING_HEADER
-       // or SENDING_ERROR.
-       size_t header_or_error_bytes_sent;
+       // or SENDING_SHORT_RESPONSE.
+       size_t header_or_short_response_bytes_sent;
 
        // Number of bytes we are into the stream (ie., the end of last send).
        // -1 means we want to send from the end of the backlog (the normal case),